setServerSideVerificationOptions static method

void setServerSideVerificationOptions({
  1. required String userId,
  2. String? customData,
})

Set server-side verification options for rewarded ads This updates the configuration to include server-side verification Note: For existing loaded ads, you need to reload them to apply new options

Implementation

static void setServerSideVerificationOptions({
  required String userId,
  String? customData,
}) {
  final options = ServerSideVerificationOptions(
    userId: userId,
    customData: customData,
  );

  // Update the configuration with new server-side verification options
  config = MonetizationConfig(
    maxAdsPerSession: config.maxAdsPerSession,
    minInterstitialInterval: config.minInterstitialInterval,
    minRewardedInterval: config.minRewardedInterval,
    serverSideVerificationOptions: options,
  );
}