PremiumManager class

Premium user management for ad-free experience

Constructors

PremiumManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

isPremiumUser bool
no setter

Static Methods

setPremiumStatus({required bool isPremium}) → void
Set premium status and manage ads accordingly
shouldShowAds() bool
Check if ads should be shown (not premium user)