ProductionAdIdManager class

Production Ad ID Manager for monetization Replace the placeholder IDs with your actual AdMob and AppLovin ad unit IDs

Inheritance

Constructors

ProductionAdIdManager()
const

Properties

admobAdIds AppAdIds?
Pass null if you wish not to implement admob ads
no setteroverride
appLovinAdIds AppLovinAdIds?
Pass null if you wish not to implement AppLovin ads
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited