AdEvent class
AdEvent is used to pass data inside event streams in ads instance You can use this to distinguish between different event types and each event type has a data attached to it.
Constructors
- AdEvent({required AdEventType type, required AdNetwork adNetwork, AdUnitType? adUnitType, Object? data, String? error})
Properties
- adNetwork → AdNetwork
-
final
- adUnitType → AdUnitType?
-
final
- data → Object?
-
Any custom data along with the event
final
- error → String?
-
In case of AdEventType.adFailedToLoad & AdEventType.adFailedToShow or in any error case
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → AdEventType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited