AdAnalytics class
Ad analytics and performance tracking
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getAnalytics(
) → Map< String, dynamic> - Get analytics data
-
resetAnalytics(
) → void - Reset analytics (call monthly/weekly)
-
trackAdEvent(
AdEvent event) → void - Track ad events for analytics