MonetizationConfig class
Configuration class for monetization settings
Constructors
-
MonetizationConfig({int maxAdsPerSession = 10, int minInterstitialInterval = 60, int minRewardedInterval = 30, ServerSideVerificationOptions? serverSideVerificationOptions, Map<
String, RewardConfig> rewardConfigs = const {}}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxAdsPerSession → int
-
final
- minInterstitialInterval → int
-
final
- minRewardedInterval → int
-
final
-
rewardConfigs
→ Map<
String, RewardConfig> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serverSideVerificationOptions → ServerSideVerificationOptions?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited